@@ -359,9 +359,6 @@ struct Client
 #define FLAGS2_CBURST       0x10000  /* connection burst being sent */
 
 #define FLAGS2_DOINGLIST    0x20000  /* client is doing a list */
-#ifdef IDLE_CHECK
-#define FLAGS2_IDLE_LINED   0x40000
-#endif
 #define FLAGS2_ALREADY_EXITED   0x80000         /* kludge grrrr */
 #define FLAGS2_IP_HIDDEN        0x200000        /* client IP should be hidden
                                                    from non opers */
@@ -425,11 +422,6 @@ struct Client
 #define SetIPHidden(x)          ((x)->flags2 |= FLAGS2_IP_HIDDEN)
 #define IsIPHidden(x)           ((x)->flags2 & FLAGS2_IP_HIDDEN)
 
-#ifdef IDLE_CHECK
-#define SetIdlelined(x)         ((x)->flags2 |= FLAGS2_IDLE_LINED)
-#define IsIdlelined(x)          ((x)->flags2 & FLAGS2_IDLE_LINED)
-#endif
-
 #define CBurst(x)               ((x)->flags2 & FLAGS2_CBURST)
 
 /*
