@@ -73,7 +73,7 @@
  * This is how many 'buffer connections' we allow... 
  * Remember, MAX_BUFFER + MAX_CLIENTS can't exceed HARD_FDLIMIT :)
  */
-#define MAX_BUFFER      60
+#define MAX_BUFFER      50
 
 #if defined(__CYGWIN__)
 #undef HARD_FDLIMIT_
@@ -500,6 +500,10 @@
  */
 #define NO_DEFAULT_INVISIBLE
 
+/* DEFAULT_WALLOP - clients +w by default
+ */
+#undef DEFAULT_WALLOP
+
 /*
  * The compression level used for zipped links. (Suggested values: 1 to 5)
  * Above 4 will only give a rather marginal increase in compression for a
@@ -703,30 +707,6 @@
  */
 #undef  LIMIT_UH
 
-/* IDLE_CHECK
- * If this is defined, each client is checked for excessive idleness
- * This adds some CPU... you might not want to use this on a large server.
- * However, if defined, and a client is discovered idling more than
- * IDLE_TIME minutes, it is t-klined for 1 minute to discourage
- * reconnects. The idle time is settable via /quote set
- * /quote set idletime
- *
- * -Dianora
- *
- * OPER_IDLE allows operators to remain idle when they idle
- * beyond the idle limit
- *
- * OPER_IDLE is fundamentally opposed to the objective of
- * removing all special powers from O:lines and moving to
- * capabilities. Don't use it.
- *  -- asuffield
- */
-#undef  IDLE_CHECK
-#define IDLE_TIME 20160
-/* (deprecated)
- * #undef OPER_IDLE
- */
-
 /* SEND_FAKE_KILL_TO_CLIENT - make the client think it's being /KILL'ed
  * 
  * This was originally intended to prevent clients from reconnecting to the
@@ -795,11 +775,6 @@
  */
 #define TSDELTA
 
-/*
- * Use full-blown K:lines with timeouts in the hold field, rather than tKlines
- */
-#define FULL_TIMEOUT_KLINES
-
 /*
  * How long to keep UNKLINEs in the anti-split cache for? (default: 24 hours)
  */
@@ -935,6 +910,11 @@
  */
 #define MAXCHANNELSPERUSER  20  /* Recommended value: 20 */
 
+/* MAXCHANNELSPERUSER_LARGE -
+ * Max number of channels a user with umode +u is allowed to join.
+ */
+#define MAXCHANNELSPERUSER_LARGE  100
+
 /* SENDQ_ALWAYS - should always be defined.
  * SendQ-Always causes the server to put all outbound data into the sendq and
  * flushing the sendq at the end of input processing. This should cause more
@@ -1154,10 +1134,6 @@
 #define MIN_SPAM_TIME 60
 #endif
 
-#ifdef IDLE_CHECK
-#define MIN_IDLETIME 1800
-#endif
-
 /* MAX_MAP_NODES - maximum number of nodes for /MAP command
  *  if there actual nodes than this, then command returns
  *  without MAP results.
