@@ -241,12 +241,6 @@ Info MyInformation[] = {
   { "I_LINES_OPER_ONLY", "OFF", 0, "Allow only Operators to use STATS I" },
 #endif /* I_LINES_OPER_ONLY */
 
-#ifdef IDLE_CHECK
-  { "IDLE_CHECK", "ON", 0, "Check Clients for Excessive Idleness" },
-#else
-  { "IDLE_CHECK", "OFF", 0, "Check Clients for Excessive Idleness" },
-#endif /* IDLE_CHECK */
-
 #ifdef IDLE_TIME
   { "IDLE_TIME", "", IDLE_TIME, "Delay (in minutes) before a client is considered idle" },
 #else
