@@ -266,10 +266,6 @@ time_t check_pings(time_t currenttime)
   int           die_index=0;            /* index into list */
   char          ping_time_out_buffer[64];   /* blech that should be a define */
 
-#if defined(IDLE_CHECK) && defined(SEND_FAKE_KILL_TO_CLIENT)
-  int           fakekill=0;
-#endif /* IDLE_CHECK && SEND_FAKE_KILL_TO_CLIENT */
-
                                         /* of dying clients */
   dying_clients[0] = (struct Client *)NULL;   /* mark first one empty */
 
@@ -428,41 +424,6 @@ time_t check_pings(time_t currenttime)
             }
         }
 
-#ifdef IDLE_CHECK
-      if (IsPerson(cptr))
-        {
-          if( !IsElined(cptr) &&
-              IDLETIME && 
-#ifdef OPER_IDLE
-              !IsAnOper(cptr) &&
-#endif /* OPER_IDLE */
-              !IsIdlelined(cptr) && 
-              ((CurrentTime - cptr->user->last) > IDLETIME))
-            {
-              struct ConfItem *aconf;
-
-              dying_clients[die_index] = cptr;
-              dying_clients_reason[die_index++] = "Idle time limit exceeded";
-#if defined(SEND_FAKE_KILL_TO_CLIENT) && defined(IDLE_CHECK)
-              fakekill = 1;
-#endif /* SEND_FAKE_KILL_TO_CLIENT && IDLE_CHECK */
-              dying_clients[die_index] = (struct Client *)NULL;
-
-              aconf = make_conf();
-              aconf->status = CONF_KILL;
-              DupString(aconf->host, cptr->host);
-              DupString(aconf->passwd, "Idle time limit exceeded" );
-              DupString(aconf->name, cptr->username);
-              aconf->port = 0;
-              aconf->hold = CurrentTime + 60;
-              add_temp_kline(aconf);
-              sendto_ops_flag(UMODE_SKILL, "Idle time limit exceeded for %s - temp k-lining",
-			      get_client_name(cptr, HIDE_IP));
-              continue;         /* and go examine next fd/cptr */
-            }
-        }
-#endif
-
 #ifdef REJECT_HOLD
       if (IsRejectHeld(cptr))
         {
@@ -617,32 +578,10 @@ time_t check_pings(time_t currenttime)
               sendto_ops_flag(UMODE_DEBUG, "Client already exited doing ping timeout (%p)", (void *)cptr);
             }
           else
-            (void)exit_client(cptr, cptr, &me, ping_time_out_buffer );
-          cptr->flags2 |= FLAGS2_ALREADY_EXITED;
+            exit_client(cptr, cptr, &me, ping_time_out_buffer );
         }
       else
-#if defined(SEND_FAKE_KILL_TO_CLIENT) && defined(IDLE_CHECK)
         {
-	  char *killer;
-	  killer = "AutoKILL";
-          if (fakekill)
-            sendto_prefix_one(cptr, cptr, ":%s KILL %s :(%s)", killer,
-            cptr->name, dying_clients_reason[die_index]);
-          /* ugh. this is horrible.
-           * but I can get away with this hack because of the
-           * block allocator, and right now,I want to find out
-           * just exactly why occasional already bit cleared errors
-           * are still happening
-           */
-          if(cptr->flags2 & FLAGS2_ALREADY_EXITED)
-            {
-              sendto_ops_flag(UMODE_DEBUG, "Client already exited %p", (void *)cptr);
-            }
-          else
-            (void)exit_client(cptr, cptr, &me, dying_clients_reason[die_index]);
-          cptr->flags2 |= FLAGS2_ALREADY_EXITED;
-        }
-#else 
           /* ugh. this is horrible.
            * but I can get away with this hack because of the
            * block allocator, and right now,I want to find out
@@ -654,9 +593,9 @@ time_t check_pings(time_t currenttime)
               sendto_ops_flag(UMODE_DEBUG, "Client already exited (%p)", (void *)cptr);
             }
           else
-            (void)exit_client(cptr, cptr, &me, dying_clients_reason[die_index]);
-          cptr->flags2 |= FLAGS2_ALREADY_EXITED;          
-#endif /* SEND_FAKE_KILL_TO_CLIENT && IDLE_CHECK */
+            exit_client(cptr, cptr, &me, dying_clients_reason[die_index]);
+        }
+      cptr->flags2 |= FLAGS2_ALREADY_EXITED;
     }
 
   rehashed = 0;
