@@ -576,10 +576,6 @@ static void initialize_global_set_options(void)
   KILLNUM = FLUD_NUM + 2;
 #endif
 
-#ifdef IDLE_CHECK
-  IDLETIME = MIN_IDLETIME;
-#endif
-
 #ifdef ANTI_SPAMBOT
   SPAMTIME = MIN_JOIN_LEAVE_TIME;
   SPAMNUM = MAX_JOIN_LEAVE_COUNT;
