@@ -68,9 +68,7 @@ static int LockedFile(const char *);
 static void WritePendingLines(const char *);
 static void WriteKline(const char *, aClient *, aClient *,
                        const char *, const char *, const char *, 
-#ifdef FULL_TIMEOUT_KLINES
 		       time_t until,
-#endif
                        time_t when);
 static void WriteDline(const char *, aClient *,
                        const char *, const char *, const char *);
@@ -205,9 +203,7 @@ WritePendingLines(const char *filename)
 		 PendingLines->user,
 		 PendingLines->host,
 		 PendingLines->reason,
-#ifdef FULL_TIMEOUT_KLINES
 		 PendingLines->until,
-#endif
 		 PendingLines->when);
     }
     else
@@ -237,9 +233,7 @@ WriteKline()
 static void
 WriteKline(const char *filename, aClient *sptr, aClient *rcptr,
            const char *user, const char *host, const char *reason, 
-#ifdef FULL_TIMEOUT_KLINES
 	   time_t until,
-#endif
            time_t when)
 
 {
@@ -300,7 +294,6 @@ WriteKline(const char *filename, aClient *sptr, aClient *rcptr,
   if (safe_write(sptr, filename, out, buffer) == (-1))
     return;
 
-#ifdef FULL_TIMEOUT_KLINES
   if (until)
     ircsnprintf(buffer, 1024, "K:%s:%s:%s:::%d:%d\n",
 		host,
@@ -309,7 +302,6 @@ WriteKline(const char *filename, aClient *sptr, aClient *rcptr,
 		until,
 		when);
   else
-#endif
     ircsnprintf(buffer, 1024, "K:%s:%s:%s::::%d\n",
 		host,
 		reason,
@@ -735,52 +727,25 @@ m_kline(aClient *cptr,
   DupString(aconf->user, user);
   aconf->port = 0;
 
-#ifndef FULL_TIMEOUT_KLINES
-  if(temporary_kline_time)
+  aconf->hold = temporary_kline_time_seconds ? (CurrentTime + temporary_kline_time_seconds) : 0;
+  if(ip_kline)
     {
-      ircsnprintf(buffer, 512,
-		  "Temporary K-line %d min by %s. - %s (%s)",
-		  temporary_kline_time,
-		  sptr->name,
-		  reason ? reason : "No reason",
-		  current_date);
-      DupString(aconf->passwd, buffer );
-#endif
-      aconf->hold = temporary_kline_time_seconds ? (CurrentTime + temporary_kline_time_seconds) : 0;
-      if(ip_kline)
-        {
-          aconf->ip = ip;
-          aconf->ip_mask = ip_mask;
-        }
-#ifndef FULL_TIMEOUT_KLINES
-      add_temp_kline(aconf);
-      rehashed = YES;
-      dline_in_progress = NO;
-      nextping = CurrentTime;
-      sendto_local_ops_flag(UMODE_SERVNOTICE, "%s added temporary %d min. K-Line for [%s@%s] [%s]",
-			    rcptr ? rcptr->name : parv[0],
-			    temporary_kline_time,
-			    user,
-			    host,
-			    reason ? reason : "No reason");
-      return 0;
+      aconf->ip = ip;
+      aconf->ip_mask = ip_mask;
+    }
+
+  /* This is a K:line being propagated, retain the old reason */
+  if (reason && strchr(reason, ';') && IsServer(sptr))
+    {
+      DupString(aconf->passwd, reason);
     }
   else
-#endif
     {
-      /* This is a K:line being propagated, retain the old reason */
-      if (reason && strchr(reason, ';') && IsServer(sptr))
-	{
-	  DupString(aconf->passwd, reason);
-	}
-      else
-	{
-	  ircsnprintf(buffer, 512, "%s; %s (%s)",
-		      rcptr ? rcptr->name : sptr->name,
-		      reason ? reason : "No reason",
-		      current_date);
-	  DupString(aconf->passwd, buffer);
-	}
+      ircsnprintf(buffer, 512, "%s; %s (%s)",
+                  rcptr ? rcptr->name : sptr->name,
+                  reason ? reason : "No reason",
+                  current_date);
+      DupString(aconf->passwd, buffer);
     }
   ClassPtr(aconf) = find_class(0);
 
@@ -816,7 +781,6 @@ m_kline(aClient *cptr,
 	}
     }
 
-#ifdef FULL_TIMEOUT_KLINES
   if(temporary_kline_time)
     sendto_local_ops_flag(UMODE_SERVNOTICE, "%s added K-Line for [%s@%s] [%s], expiring at %.1ld (%d minutes)",
 			  rcptr ? rcptr->name : sptr->name,
@@ -825,7 +789,6 @@ m_kline(aClient *cptr,
 			  reason ? reason : "No reason",
 			  aconf->hold, temporary_kline_time);
   else
-#endif
     sendto_local_ops_flag(UMODE_SERVNOTICE, "%s added K-Line for [%s@%s] [%s]",
 			  rcptr ? rcptr->name : sptr->name,
 			  user,
@@ -861,9 +824,7 @@ m_kline(aClient *cptr,
 
     pptr->rcptr = rcptr;
 
-#ifdef FULL_TIMEOUT_KLINES
     pptr->until = aconf->hold;
-#endif
 
     if (IsClient(sptr))
       sendto_one(sptr,
@@ -893,9 +854,7 @@ m_kline(aClient *cptr,
 	     user,
 	     host,
 	     aconf->passwd,
-#ifdef FULL_TIMEOUT_KLINES
 	     aconf->hold,
-#endif
 	     CurrentTime);
 
   rehashed = YES;
