@@ -178,11 +178,6 @@ static  int     m_message(struct Client *cptr,
   if( IsChanPrefix(*nick)
       && (IsPerson(sptr) && (chptr = hash_find_channel(nick, NullChn))))
     {
-#ifdef  IDLE_CHECK
-      /* reset idle time for message only if target exists */
-      if(MyClient(sptr) && sptr->user)
-        sptr->user->last = CurrentTime;
-#endif
 #ifdef FLUD
 #ifdef DEATHFLUD
       if(!notice && check_for_ctcp(parv[2])
@@ -214,6 +209,11 @@ static  int     m_message(struct Client *cptr,
         case 0:
           sendto_channel_message_butone(cptr, sptr, chptr, cmd, parv[2]);
           break;
+        case MODE_QUIETUNIDENT:
+          if (!notice)
+            sendto_one(sptr, form_str(ERR_QUIETUNIDENT),
+                       me.name, parv[0], nick);
+          break;
         case MODE_MODERATED:
           if (chptr->mode.mode & MODE_OPMODERATE)
             {
@@ -277,11 +277,6 @@ static  int     m_message(struct Client *cptr,
 
       if ( (chptr = hash_find_channel(nick+1, NullChn)) )
         {
-#ifdef  IDLE_CHECK
-          /* reset idle time for message only if target exists */
-          if(MyClient(sptr) && sptr->user)
-            sptr->user->last = CurrentTime;
-#endif
 #ifdef FLUD
 #ifdef DEATHFLUD
           if(!notice && check_for_ctcp(parv[2])
@@ -336,11 +331,6 @@ static  int     m_message(struct Client *cptr,
   */
   if ((acptr = find_person(nick, NULL)))
     {
-#ifdef  IDLE_CHECK
-      /* reset idle time for message only if target exists */
-      if(MyClient(sptr) && sptr->user)
-        sptr->user->last = CurrentTime;
-#endif
 #ifdef FLUD
 #ifdef DEATHFLUD
       if(!notice && MyConnect(sptr) && check_for_ctcp(parv[2])
@@ -461,15 +451,6 @@ static  int     m_message(struct Client *cptr,
       }
 #endif
 
-
-#ifdef  IDLE_CHECK
-      /* reset idle time for message only if its not to self */
-      if (sptr != acptr)
-        {
-          if(sptr->user)
-            sptr->user->last = CurrentTime;
-        }
-#endif
       msgs++;
       continue;
     }
