@@ -240,32 +240,6 @@ int m_set(struct Client *cptr, struct Client *sptr, int parc, char *parv[])
           return 0;
           break;
 
-#ifdef IDLE_CHECK
-          case TOKEN_IDLETIME:
-            if(parc > 2)
-              {
-                int newval = atoi(parv[2]);
-                if(newval == 0)
-                  {
-                    sendto_ops_flag(UMODE_SERVNOTICE, "%s has disabled IDLE_CHECK",
-					   parv[0]);
-                    IDLETIME = 0;
-                  }
-                else
-                  {
-                    sendto_ops_flag(UMODE_SERVNOTICE, "%s has changed IDLETIME to %i",
-					   parv[0], newval);
-                    IDLETIME = (newval*60);
-                  }
-              }
-            else
-              {
-                sendto_one(sptr, ":%s NOTICE %s :IDLETIME is currently %i",
-                           me.name, parv[0], IDLETIME/60);
-              }
-            return 0;
-            break;
-#endif
 #ifdef FLUD
           case TOKEN_FLUDNUM:
             if(parc > 2)
