@@ -59,6 +59,7 @@
 #include "m_commands.h"
 #include "umodes.h"
 #include "s_log.h"
+#include "m_kline.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -873,38 +874,21 @@ aConfItem* find_matching_mtrie_conf(const char* host, const char* user, const ch
 
       if(kline_aconf)
 	{
-#ifdef FULL_TIMEOUT_KLINES
 	  if(kline_aconf->hold)
 	    {
 	      /* Hello. One of the new timeout K:lines. */
 	      if(kline_aconf->hold <= CurrentTime)
 		{
-		  /* And it's expired. Remove it and return the I:line instead */
-		  char *parv[2];
-		  static char buf[USERLEN + HOSTLEN + 1 + 1], buf2[USERLEN + HOSTLEN + 1 + 1];
-		  if ((strlen(kline_aconf->user) == 0) || (strlen(kline_aconf->host) == 0))
-		    return NULL;
-		  parv[0] = me.name;
-		  ircsnprintf(buf, USERLEN + HOSTLEN + 1 + 1, "%s@%s", kline_aconf->user, kline_aconf->host);
-		  strncpy_irc(buf2, buf, USERLEN + HOSTLEN + 1 + 1);
-		  parv[1] = buf2;
-		  sendto_ops_flag(UMODE_SERVNOTICE, "Expiring K:line on %s", buf);
-		  if (m_unkline(&me, &me, 2, parv) != 0)
-		    {
-		      sendto_ops_flag(UMODE_SERVNOTICE, "Cannot remove timed K:line for %s! Rejecting connection instead", buf);
-		      return ((aConfItem*) NULL);
-		    }
+                  if (!unkline_conf(kline_aconf))
+                    return NULL;
+
 		  /* OK, I expired a K:line. Rehash, go around, and try again */
 		  if (rehash(&me, &me, 0) != 0)
-                    {
-		      return ((aConfItem*) NULL);
-                    }
-		  /* And rehash the remote servers */
-		  sendto_serv_butone(NULL, ":%s REHASH ALL *", me.name);
+                    return NULL;
+
 		  continue;
 		}
 	    }
-#endif
 	  return(kline_aconf);
 	}
       else
@@ -1561,13 +1545,6 @@ char *show_iline_prefix(aClient *sptr,aConfItem *aconf,char *name)
     if (IsConfFlined(aconf))
       *prefix_ptr++ = '>';
 
-#ifdef IDLE_CHECK  
-#ifdef E_LINES_OPER_ONLY
-  if(CanSeeElines(sptr))
-#endif
-    if (IsConfIdlelined(aconf))
-      *prefix_ptr++ = '<';
-#endif
   *prefix_ptr = '\0';
 
   strncat(prefix_of_host,name,MAXPREFIX);
