@@ -503,7 +503,7 @@ static time_t timeout_query_list(time_t now)
       else {
         request->sentat = now;
         request->timeout += request->timeout / 2;
-        logprintf(L_WARN, "DNS lookup timed out, new timeout %lu, retries %d", request->timeout, request->retries);
+        logprintf(L_WARN, "DNS lookup timed out, new timeout %lu, retries %d", (long unsigned)request->timeout, request->retries);
         resend_query(request);
 #ifdef DEBUG
         Debug((DEBUG_INFO,"r %x now %d retry %d c %x",
