@@ -485,7 +485,7 @@ static void sendnick_TS(struct Client *cptr, struct Client *acptr)
   if (IsPerson(acptr))
     {
       sendto_one(cptr, "NICK %s %d %lu +%s %s %s %s %s :%s", acptr->name, 
-                 acptr->hopcount + 1, acptr->tsinfo, umodes_as_string(&acptr->umodes),
+                 acptr->hopcount + 1, (long unsigned)acptr->tsinfo, umodes_as_string(&acptr->umodes),
                  acptr->username, acptr->host,
                  acptr->user->server, inetntoa((char *)&acptr->ip.s_addr), acptr->info);
       {
@@ -728,7 +728,7 @@ int server_estab(struct Client *cptr)
     ClearCap(cptr, CAP_ZIP);
 #endif /* ZIP_LINKS */
 
-  sendto_one(cptr,"SVINFO %d %d 0 :%lu", TS_CURRENT, TS_MIN, CurrentTime);
+  sendto_one(cptr,"SVINFO %d %d 0 :%lu", TS_CURRENT, TS_MIN, (long unsigned)CurrentTime);
   
   det_confs_butmask(cptr, CONF_LEAF|CONF_HUB|CONF_NOCONNECT_SERVER);
   release_client_dns_reply(cptr);
@@ -878,7 +878,10 @@ int server_estab(struct Client *cptr)
       }
     if (sent_unkline)
       sendto_one(cptr, ":%s REHASH", me.name);
-    sendto_one(cptr, ":%s BURST KLINES", me.name);
+    /* This appears to do more harm than good - propagating K:lines on
+     * demand is rare, and sending them in bulk is slow
+     */
+/*     sendto_one(cptr, ":%s BURST KLINES", me.name); */
   }
 
   /*
