@@ -810,6 +810,10 @@ static int register_user(aClient *cptr, aClient *sptr,
       sendto_one(sptr, form_str(RPL_PROTOCTL), me.name, parv[0],
 		 MAXMODEPARAMS, MAXCHANNELSPERUSER, NICKLEN, USERLEN, HOSTLEN,
 		 TOPICLEN, TOPICLEN, CHANNELLEN, KEYLEN);
+
+      if (AnyBits(sptr->umodes))
+        sendto_one(sptr, "MODE %s :+%s", sptr->name, umodes_as_string(&sptr->umodes));
+
       /* Increment the total number of clients since (re)start */
       Count.totalrestartcount++;
       show_lusers(sptr, sptr, 1, parv);
@@ -920,7 +924,7 @@ static int register_user(aClient *cptr, aClient *sptr,
   if (!IsHoneypot(sptr))
     {
       sendto_serv_butone(cptr, "NICK %s %d %lu +%s %s %s %s %s :%s",
-                         nick, sptr->hopcount+1, sptr->tsinfo,
+                         nick, sptr->hopcount+1, (long unsigned)sptr->tsinfo,
                          umodes_as_string(&sptr->umodes),
                          sptr->username, sptr->host, user->server,
                          inetntoa((char *)&sptr->ip.s_addr),
@@ -1114,16 +1118,6 @@ report_and_set_user_flags(aClient *sptr,aConfItem *aconf)
                  ":%s NOTICE %s :*** You are exempt from user limits. congrats.",
                  me.name,sptr->name);
     }
-#ifdef IDLE_CHECK
-  /* If this user is exempt from idle time outs */
-  if(IsConfIdlelined(aconf))
-    {
-      SetIdlelined(sptr);
-      sendto_one(sptr,
-         ":%s NOTICE %s :*** You are exempt from idle limits. congrats.",
-                 me.name,sptr->name);
-    }
-#endif
 }
 
 /*
@@ -1250,7 +1244,7 @@ nickkilldone(struct Client *cptr, struct Client *sptr, int parc,
                   add_history(sptr,1);
               
                   sendto_serv_butone(cptr, ":%s NICK %s :%lu",
-                                     parv[0], nick, sptr->tsinfo);
+                                     parv[0], nick, (long unsigned)sptr->tsinfo);
 		  /* This global message will reset the idle time everywhere, so
 		   *  reset the last_sent counter as well
 		   */
@@ -1281,7 +1275,7 @@ nickkilldone(struct Client *cptr, struct Client *sptr, int parc,
             {
               add_history(sptr,1);
               sendto_serv_butone(cptr, ":%s NICK %s :%lu",
-                                 parv[0], nick, sptr->tsinfo);
+                                 parv[0], nick, (long unsigned)sptr->tsinfo);
 	      sptr->user->last_sent = CurrentTime;
 
               sendto_local_ops_flag(UMODE_NCHANGE,
@@ -1628,7 +1622,7 @@ int m_nick(aClient *cptr, aClient *sptr, int parc, char *parv[])
 #ifdef LOCAL_NICK_COLLIDE
       /* just propogate it through */
       sendto_serv_butone(cptr, ":%s NICK %s :%lu",
-                         parv[0], nick, sptr->tsinfo);
+                         parv[0], nick, (long unsigned)sptr->tsinfo);
 #endif
       /*
       ** A new NICK being introduced by a neighbouring
@@ -1960,7 +1954,10 @@ static int do_user(char* nick, aClient* cptr, aClient* sptr,
           return 0;
         }
 #ifndef NO_DEFAULT_INVISIBLE
-      SetBit(sptr->umodes,UMODE_INVISIBLE);
+      SetUmode(sptr, UMODE_INVISIBLE);
+#endif
+#ifdef DEFAULT_WALLOP
+      SetUmode(sptr, UMODE_WALLOP);
 #endif
 
       if (IsInvisible(sptr))
