@@ -3,7 +3,7 @@
  *   Copyright (C) 1990 Jarkko Oikarinen and
  *                    University of Oulu, Computing Center
  *             (C) 2001,2002 Andrew Suffield
- *                    <asuffield@users.sourceforge.net>
+ *                    <asuffield@freenode.net>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -335,7 +335,6 @@ send_message(aClient *to, char *msg, int len)
 int send_queued(aClient *to)
 {
   const char *msg;
-  int len, rlen;
 #ifdef ZIP_LINKS
   int more = NO;
 #endif
@@ -371,9 +370,10 @@ int send_queued(aClient *to)
     if (DBufLength(&to->sendQ) > 0)
       more = 1;
     else {
-      msg = zip_buffer(to, NULL, &len, 1);
+      int zlen;
+      msg = zip_buffer(to, NULL, &zlen, 1);
 
-      if (len == -1)
+      if (zlen == -1)
 	{
 	  struct ConfItem *c_conf = find_conf_name(to->confs, to->name, CONF_CONNECT_SERVER);
 	  if (c_conf)
@@ -381,14 +381,16 @@ int send_queued(aClient *to)
 	  return dead_link(to, "fatal error in zip_buffer()");
 	}
 
-      if (!dbuf_put(&to->sendQ, msg, len))
+      if (!dbuf_put(&to->sendQ, msg, zlen))
         return dead_link(to, "Buffer allocation error for %s");
     }
   } /* if ((to->flags2 & FLAGS2_ZIP) && to->zip->outcount) */
 #endif /* ZIP_LINKS */
 
   while (DBufLength(&to->sendQ) > 0) {
-    msg = dbuf_map(&to->sendQ, (size_t *) &len);
+    size_t len;
+    int rlen;
+    msg = dbuf_map(&to->sendQ, &len);
 
     /* Returns always len > 0 */
     if ((rlen = deliver_it(to, msg, len)) < 0)
@@ -408,7 +410,7 @@ int send_queued(aClient *to)
       strncpy_irc(param, to->name, HOSTLEN + 1);
       m_list(to, to, 1, parv);
     }
-    if (rlen < len) {    
+    if (rlen < (int)len) {    
       /* ..or should I continue until rlen==0? */
       /* no... rlen==0 means the send returned EWOULDBLOCK... */
       break;
@@ -420,10 +422,11 @@ int send_queued(aClient *to)
       ** The sendQ is now empty, compress what's left
       ** uncompressed and try to send it too
       */
+      int zlen;
       more = 0;
-      msg = zip_buffer(to, NULL, &len, 1);
+      msg = zip_buffer(to, NULL, &zlen, 1);
 
-      if (len == -1)
+      if (zlen == -1)
 	{
 	  struct ConfItem *c_conf = find_conf_name(to->confs, to->name, CONF_CONNECT_SERVER);
 	  if (c_conf)
@@ -431,7 +434,7 @@ int send_queued(aClient *to)
 	  return dead_link(to, "fatal error in zip_buffer()");
 	}
 
-      if (!dbuf_put(&to->sendQ, msg, len))
+      if (!dbuf_put(&to->sendQ, msg, zlen))
         return dead_link(to, "Buffer allocation error for %s");
     } /* if (DBufLength(&to->sendQ) == 0 && more) */
 #endif /* ZIP_LINKS */      
